==> mmemoji-0.5.0-py3-none-any.whl: mmemoji/commands/create.py <==
from typing import List

import click
from requests import HTTPError

from mmemoji import Emoji
from mmemoji.decorators import EmojiContext, parse_global_options


@click.command(help="Create custom Emojis")
@click.argument("images", type=click.File("rb", lazy=True), nargs=-1)
@click.option(
    "-f",
    "--force",
    is_flag=True,
    help="""
if the emoji exists, remove it and proceed \
(this option is ignored when the -i or -n option is also used)
""",
)
@click.option(
    "-n",
    "--no-clobber",
    is_flag=True,
    help="do not overwrite an existing file (overrides -i option)",
)
@click.option(
    "-i", "--interactive", is_flag=True, help="prompt before overwrite"
)
@parse_global_options
def cli(
    ctx: EmojiContext,
    images: List[str],
    force: bool,
    no_clobber: bool,
    interactive: bool,
) -> None:
    emojis = []

    try:
        with click.progressbar(images, show_pos=True) as pb_images:
            for image in pb_images:
                emoji = Emoji(ctx.mattermost, image.name)

                if emoji.metadata and not no_clobber and interactive:
                    force = click.confirm(
                        f'overwrite "{emoji.name}"?', err=True
                    )
                    if not force:
                        continue

                with image as img:
                    if emoji.create(img, force, no_clobber):
                        emojis.append(emoji.metadata)
    except HTTPError as e:
        raise click.ClickException(e.args[0] if e.args != () else repr(e))
    finally:
        ctx.print_dict(emojis)

==> mmemoji-0.6.0-py3-none-any.whl: mmemoji/commands/create.py <==
from typing import BinaryIO

import click
from requests import HTTPError

from mmemoji import Emoji
from mmemoji.decorators import EmojiContext, parse_global_options


@click.command(help="Create custom Emojis")
@click.argument("images", type=click.File("rb", lazy=True), nargs=-1)
@click.option(
    "-f",
    "--force",
    is_flag=True,
    help="""
if the emoji exists, remove it and proceed \
(this option is ignored when the -i or -n option is also used)
""",
)
@click.option(
    "-n",
    "--no-clobber",
    is_flag=True,
    help="do not overwrite an existing file (overrides -i option)",
)
@click.option(
    "-i", "--interactive", is_flag=True, help="prompt before overwrite"
)
@parse_global_options
def cli(
    ctx: EmojiContext,
    images: list[BinaryIO],
    force: bool,
    no_clobber: bool,
    interactive: bool,
) -> None:
    emojis = []

    try:
        with click.progressbar(images, show_pos=True) as pb_images:
            for image in pb_images:
                emoji = Emoji(ctx.mattermost, image.name)

                if emoji.metadata and not no_clobber and interactive:
                    force = click.confirm(
                        f'overwrite "{emoji.name}"?', err=True
                    )
                    if not force:
                        continue

                with image as img:
                    if emoji.create(img, force, no_clobber):
                        emojis.append(emoji.metadata)
    except HTTPError as e:
        raise click.ClickException(
            e.args[0] if e.args != () else repr(e)
        ) from e
    finally:
        ctx.print_dict(emojis)
